# coding: utf-8
# /*##########################################################################
#
# Copyright (c) 2004-2016 European Synchrotron Radiation Facility
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
#
# ###########################################################################*/
"""Set of icons for buttons.

Use :func:`getQIcon` to create Qt QIcon from the name identifying an icon.
"""

__authors__ = ["F. Mengoni", "V. A. Sole", "T. Vincent"]
__license__ = "MIT"
__date__ = "01/04/2016"


import sys as _sys

from . import qt as _qt


def getQIcon(name):
    """Create a QIcon from its name.

    :param str name: Name of the icon, in one of the defined icons
                     in this module.
    :return: Corresponding QIcon
    :raises: ValueError when name is not known
    """
    return _qt.QIcon(getQPixmap(name))


def getQPixmap(name):
    """Create a QPixmap from its name.

    :param str name: Name of the icon, in one of the defined icons
                     in this module.
    :return: Corresponding QPixmap
    :raises: ValueError when name is not known
    """
    if name.startswith('_') or name in ('getQIcon', 'getQPixmap'):
        raise ValueError('Not an icon name: %s' % name)

    attr_name = name.replace('-', '_')

    try:
        icon = getattr(_sys.modules[__name__], attr_name)
    except AttributeError:
        raise ValueError('Not an icon name: %s' % name)
    return _qt.QPixmap(icon)


colormap = [
    "32 32 99 2",
    "  	c None",
    ". 	c #F9A240",
    "+ 	c #F9A13D",
    "@ 	c #F99F39",
    "# 	c #F89A2C",
    "$ 	c #F99E37",
    "% 	c #FDCC96",
    "& 	c #FFE0BF",
    "* 	c #FBB263",
    "= 	c #F7941E",
    "- 	c #F89C32",
    "; 	c #F99E35",
    "> 	c #FED9B1",
    ", 	c #FFFFFF",
    "' 	c #FAAC55",
    ") 	c #F89B2F",
    "! 	c #F89827",
    "~ 	c #F9A545",
    "{ 	c #F79725",
    "] 	c #FCBF7C",
    "^ 	c #FEF7EE",
    "/ 	c #F9A342",
    "( 	c #FDD3A3",
    "_ 	c #F99E36",
    ": 	c #F1EDF6",
    "< 	c #CABCDC",
    "[ 	c #E2DBEC",
    "} 	c #FEEFDC",
    "| 	c #F99D34",
    "1 	c #FDC689",
    "2 	c #F89828",
    "3 	c #FEE8CE",
    "4 	c #A286BE",
    "5 	c #6C3895",
    "6 	c #662D91",
    "7 	c #73439A",
    "8 	c #9170B1",
    "9 	c #F89726",
    "0 	c #F89929",
    "a 	c #BFAED4",
    "b 	c #FDD1A0",
    "c 	c #CAEBFC",
    "d 	c #50CAF5",
    "e 	c #00B5F1",
    "f 	c #00AEEF",
    "g 	c #B5A0CD",
    "h 	c #D6CBE4",
    "i 	c #00B1F0",
    "j 	c #EBEFA6",
    "k 	c #E0E665",
    "l 	c #E2E773",
    "m 	c #F9FAE4",
    "n 	c #19C1F3",
    "o 	c #B9E5FB",
    "p 	c #FCE5EA",
    "q 	c #E4E981",
    "r 	c #D7DF21",
    "s 	c #F2F6CB",
    "t 	c #EDF8FE",
    "u 	c #A7DFF9",
    "v 	c #80D4F7",
    "w 	c #DBF1FD",
    "x 	c #DDE455",
    "y 	c #FCFDF1",
    "z 	c #F9A03A",
    "A 	c #CEE8D6",
    "B 	c #70C492",
    "C 	c #2AB673",
    "D 	c #DDEFE2",
    "E 	c #DBE244",
    "F 	c #E8EC99",
    "G 	c #F2F2F3",
    "H 	c #B4B6B9",
    "I 	c #9D9FA2",
    "J 	c #CDCDCF",
    "K 	c #91CFA7",
    "L 	c #00A651",
    "M 	c #666769",
    "N 	c #3A3A3C",
    "O 	c #727376",
    "P 	c #00A958",
    "Q 	c #81CA9C",
    "R 	c #4D4D4F",
    "S 	c #A8AAAD",
    "T 	c #FBD8E0",
    "U 	c #D8D9DA",
    "V 	c #F16E97",
    "W 	c #ED217C",
    "X 	c #F492AC",
    "Y 	c #F9C1CE",
    "Z 	c #F387A5",
    "` 	c #F5F8D8",
    " .	c #F2EBB5",
    "..	c #FCB970",
    "+.	c #FACCD7",
    "@.	c #F0A71E",
    "#.	c #F89C31",
    "$.	c #FAA74A",
    "%.	c #F8992B",
    "                                                                ",
    "                                                                ",
    "                                                                ",
    "                                                                ",
    "                                                                ",
    "                          . + @                                 ",
    "                      # $ % & * =                               ",
    "                  - ; > , , , , '                 ) ! ' ~ )     ",
    "                { ] ^ , , , , , /             ) ; ( , , , * _   ",
    "              = ( , : < < [ , } =         | ! 1 , , , , , > @   ",
    "            2 3 , 4 5 6 6 5 [ % @       { * } , , , , , , } {   ",
    "          2 3 , 7 6 6 6 6 8 : 3 9   0 $ & , , , , , , , , , =   ",
    "        { ( , a 6 6 6 6 4 , , , b * ( , , , c d e f e c , 3 #   ",
    "      | ] , , , < g h , , , , , , , , , , c i f f f e , , & _   ",
    "      0 ^ , , , , , , , , , , j k k l m , n f f f e o , , ] @   ",
    "    0 ( , , , , , , , , , p q r r r r s , t u v w , , , , ;     ",
    "    ; , , , , , , , , , , q r r r r x y , , , , , , , , > #     ",
    "  z 1 , A B C C B D , , , l r r E F , , G H I I J , , , $       ",
    "  { } K L L L L C , , , , , , , , , , G M N N N O , , 1 #       ",
    "  - , P L L L P D , , , , , , , , , G M N N N N I , ( 9         ",
    "  ' , A Q Q K D , , , , , , , , , , H N N N R S , 3 2           ",
    "  ' , , , , , , , , , , T T , , , , , U J J , , ( 2             ",
    "  ' , , , , , , , T V W W W X , , , , , , , , 1 9               ",
    "  ! , , , , , , Y W W W W W Z , , , , ` , 3 ~ )                 ",
    "  ) % , , , , , V W W W W Z , , , , ,  ...= _                   ",
    "    2 3 , , , , +.V V Z Y , , , , 3 ..@.z                       ",
    "      2 % , , , , , , , , , 3 % ~ { #.                          ",
    "        0 | ..1 1 1 1 1 ' ! # |                                 ",
    "              $./ / $.%.                                        ",
    "                                                                ",
    "                                                                ",
    "                                                                "]


document_print = [
    "32 32 148 2",
    "  	c None",
    ". 	c #2A2A2C",
    "+ 	c #2D2D2E",
    "@ 	c #353537",
    "# 	c #48484A",
    "$ 	c #4F4F51",
    "% 	c #565759",
    "& 	c #5B5C5E",
    "* 	c #616163",
    "= 	c #646567",
    "- 	c #666769",
    "; 	c #696A6C",
    "> 	c #6D6E70",
    ", 	c #707173",
    "' 	c #747578",
    ") 	c #78797C",
    "! 	c #7C7D80",
    "~ 	c #808184",
    "{ 	c #848689",
    "] 	c #898A8D",
    "^ 	c #8C8E91",
    "/ 	c #909295",
    "( 	c #95979A",
    "_ 	c #9A9C9F",
    ": 	c #9EA0A3",
    "< 	c #545557",
    "[ 	c #BCBDC0",
    "} 	c #B8B9BC",
    "| 	c #B9BBBD",
    "1 	c #BDBFC1",
    "2 	c #97999C",
    "3 	c #717274",
    "4 	c #797A7D",
    "5 	c #818285",
    "6 	c #86878A",
    "7 	c #8D8F92",
    "8 	c #939598",
    "9 	c #989A9D",
    "0 	c #9FA1A4",
    "a 	c #A5A7AA",
    "b 	c #ADAFB1",
    "c 	c #B4B6B9",
    "d 	c #C4C5C7",
    "e 	c #CCCDCF",
    "f 	c #D4D5D6",
    "g 	c #DBDCDD",
    "h 	c #E4E5E6",
    "i 	c #EDEEEE",
    "j 	c #8F9194",
    "k 	c #DCDDDE",
    "l 	c #CDCDCF",
    "m 	c #C1C2C4",
    "n 	c #B6B7BA",
    "o 	c #49494B",
    "p 	c #4E4E50",
    "q 	c #67686A",
    "r 	c #C8C9CB",
    "s 	c #6C6D6F",
    "t 	c #474749",
    "u 	c #262627",
    "v 	c #1B1B1B",
    "w 	c #515153",
    "x 	c #5C5D5F",
    "y 	c #606163",
    "z 	c #636466",
    "A 	c #696A6D",
    "B 	c #6F7072",
    "C 	c #717275",
    "D 	c #747577",
    "E 	c #76777A",
    "F 	c #7B7C7F",
    "G 	c #7E8083",
    "H 	c #78797B",
    "I 	c #454547",
    "J 	c #1D1D1E",
    "K 	c #282829",
    "L 	c #AFB1B4",
    "M 	c #BDBEC0",
    "N 	c #C5BDB9",
    "O 	c #CECFD1",
    "P 	c #DADBDD",
    "Q 	c #DFE0E1",
    "R 	c #E6E6E7",
    "S 	c #EAEBEC",
    "T 	c #EFF0F0",
    "U 	c #F4F4F4",
    "V 	c #F2896C",
    "W 	c #FAFAFB",
    "X 	c #FDFDFD",
    "Y 	c #3C3C3E",
    "Z 	c #313132",
    "` 	c #DD7358",
    " .	c #F3CEBE",
    "..	c #ED1C24",
    "+.	c #D8D9DA",
    "@.	c #414142",
    "#.	c #EB302B",
    "$.	c #CAC1BE",
    "%.	c #EF563D",
    "&.	c #F0563D",
    "*.	c #E35F44",
    "=.	c #DB866C",
    "-.	c #E96E51",
    ";.	c #EB7A5D",
    ">.	c #ECD3C8",
    ",.	c #EF9D83",
    "'.	c #ED312B",
    ").	c #F7D1C1",
    "!.	c #CFA696",
    "~.	c #D0C7C3",
    "{.	c #DDC7BD",
    "].	c #ED7B5E",
    "^.	c #F19F84",
    "/.	c #F7F8F8",
    "(.	c #242425",
    "_.	c #C3C4C6",
    ":.	c #E45F44",
    "<.	c #E2765A",
    "[.	c #E48C70",
    "}.	c #EB553C",
    "|.	c #EC302B",
    "1.	c #ED4632",
    "2.	c #BBBCBF",
    "3.	c #D3A999",
    "4.	c #D8C2B8",
    "5.	c #EB4632",
    "6.	c #E5B7A5",
    "7.	c #E7DCD7",
    "8.	c #ED553D",
    "9.	c #E66045",
    "0.	c #EA4532",
    "a.	c #D8AD9C",
    "b.	c #E4977D",
    "c.	c #D3D4D6",
    "d.	c #E76145",
    "e.	c #DCD2CE",
    "f.	c #BEC0C2",
    "g.	c #2F2F30",
    "h.	c #737477",
    "i.	c #858689",
    "j.	c #929497",
    "k.	c #999B9E",
    "l.	c #9C9EA1",
    "m.	c #A2A4A7",
    "n.	c #A7A9AC",
    "o.	c #A9ABAE",
    "p.	c #ACAEB1",
    "q.	c #898B8E",
    "                                                                ",
    "                                                                ",
    "                                                                ",
    "                                                                ",
    "                                                                ",
    "                                                                ",
    "                                                                ",
    "                                                                ",
    "        . + @ # $ % & * = - ; > , ' ) ! ~ { ] ^ / ( _ :         ",
    "      < [ } | 1 2 3 4 5 6 ] 7 8 9 0 a b c [ d e f g h i c       ",
    "      j k } | 1 2 3 4 5 6 ] 7 8 9 0 a b c [ d e f g l g m       ",
    "      j n o p & q 3 4 5 6 ] 7 8 9 0 a b c [ d e f g r d m       ",
    "      j n o p & q 3 4 5 6 ] 7 8 9 0 a b c [ d e f g h i m       ",
    "      j n o p & q 3 4 5 6 ] 7 8 9 0 a b c [ d e f g h i m       ",
    "      s 7 t u v w x y z - q A s B C D E ) F ! G 5 H c i m       ",
    "      . I u J K j L n M N r O f P Q R S T U V W X e Y Q m       ",
    "      . I o Z K j L n M ` r O f P Q R S T  ...W X e +.i m       ",
    "      . I o @.K j L n M #.$.O f P Q R S T %.&.W X e h i m       ",
    "      . I o @.K j L n M *.=.O f P -.;.>.,.'.).W X e h i m       ",
    "      . I o @.K j L n M !.#.~.f {.....].'.^./.W X e h i m       ",
    "      (.Z @ Z K j L n M _.:.<.f [.}.|...1.U /.W X e c 2.:       ",
    "              K j L n M _.3...4.5.6.7.8.,.U /.W X e             ",
    "              K j L n M _.r 9.0.5.Q R >.T U /.W X e             ",
    "              K j L n M _.r a...b.Q R S T U /.c.m a             ",
    "              K j L n M _.r O d.e.Q R S T U /.f.5               ",
    "              g.h.i.] ^ j j.( k.l.0 m.a n.o.p.q.                ",
    "                                                                ",
    "                                                                ",
    "                                                                ",
    "                                                                ",
    "                                                                ",
    "                                                                "]


document_save = [
    "32 32 13 1",
    " 	c None",
    ".	c #D1D2D4",
    "+	c #A4A6A9",
    "@	c #97999C",
    "#	c #000000",
    "$	c #FFFFFF",
    "%	c #626365",
    "&	c #D4D5D6",
    "*	c #C7C8CA",
    "=	c #C8C9CB",
    "-	c #BABCBE",
    ";	c #555658",
    ">	c #636466",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "        .......+@+...           ",
    "     ###$$$$$$$%#%$$$##         ",
    "     ###$$$$$$$%#%$$$###        ",
    "     ###$$$$$$$%#%$$$####       ",
    "     ###$$$$$$$%#%$$$#####      ",
    "     ###$$$$$$$&*&$$$######     ",
    "     ###============-#######    ",
    "     #######################    ",
    "     #######################    ",
    "     #######################    ",
    "     #######################    ",
    "     #######################    ",
    "     ###=================;##    ",
    "     ###$$$$$$$$$$$$$$$$$>##    ",
    "     ###$$$$$$$$$$$$$$$$$>##    ",
    "     ###$$$$$$$$$$$$$$$$$>##    ",
    "     ###$$$$$$$$$$$$$$$$$>##    ",
    "     ###$$$$$$$$$$$$$$$$$>##    ",
    "     ###$$$$$$$$$$$$$$$$$>##    ",
    "     ###$$$$$$$$$$$$$$$$$;##    ",
    "     #######################    ",
    "     #######################    ",
    "     ######################     ",
    "                                ",
    "                                ",
    "                                ",
    "                                "]


edit_copy = [
    "32 32 214 2",
    "  	c None",
    ". 	c #F7941E",
    "+ 	c #F8C286",
    "@ 	c #F3F3F4",
    "# 	c #F4921F",
    "$ 	c #F6931E",
    "% 	c #F7C186",
    "& 	c #C9CACC",
    "* 	c #EB8F22",
    "= 	c #F3911D",
    "- 	c #F5C085",
    "; 	c #F2F2F3",
    "> 	c #DDDEDF",
    ", 	c #616264",
    "' 	c #58585A",
    ") 	c #7E7F82",
    "! 	c #86888B",
    "~ 	c #F09120",
    "{ 	c #F79726",
    "] 	c #F2B878",
    "^ 	c #EFF0F0",
    "/ 	c #C8C9CB",
    "( 	c #B2926D",
    "_ 	c #BF976A",
    ": 	c #CEA272",
    "< 	c #F2BE83",
    "[ 	c #E98E23",
    "} 	c #EFB06B",
    "| 	c #ECEDED",
    "1 	c #F0F0F1",
    "2 	c #F7BC7A",
    "3 	c #E28B25",
    "4 	c #EFA452",
    "5 	c #E9EAEB",
    "6 	c #97999C",
    "7 	c #6F7072",
    "8 	c #D59349",
    "9 	c #D1D2D4",
    "0 	c #DB8827",
    "a 	c #F19B37",
    "b 	c #E5E6E6",
    "c 	c #95979A",
    "d 	c #3A3A3C",
    "e 	c #656668",
    "f 	c #CC822A",
    "g 	c #E1DBD4",
    "h 	c #EAEBEC",
    "i 	c #F7AA55",
    "j 	c #8C8E91",
    "k 	c #77787B",
    "l 	c #606163",
    "m 	c #C2C3C5",
    "n 	c #B9792D",
    "o 	c #E7C196",
    "p 	c #DEDFE0",
    "q 	c #919396",
    "r 	c #68696B",
    "s 	c #A9ABAE",
    "t 	c #93652E",
    "u 	c #F59D37",
    "v 	c #A2A4A7",
    "w 	c #6B6C6E",
    "x 	c #7C7D80",
    "y 	c #A3A5A8",
    "z 	c #F1F1F2",
    "A 	c #F6A954",
    "B 	c #EDA351",
    "C 	c #D1D2D3",
    "D 	c #8D612D",
    "E 	c #EB8F21",
    "F 	c #EBB880",
    "G 	c #EDEEEE",
    "H 	c #EEEFEF",
    "I 	c #F1A653",
    "J 	c #EAA04D",
    "K 	c #D7CBBD",
    "L 	c #CFD0D2",
    "M 	c #B5B7B9",
    "N 	c #ACAEB1",
    "O 	c #8B602D",
    "P 	c #D88219",
    "Q 	c #FBB263",
    "R 	c #A38A6C",
    "S 	c #6C6D6F",
    "T 	c #C98B45",
    "U 	c #EEA656",
    "V 	c #F89F38",
    "W 	c #D7C5B1",
    "X 	c #666769",
    "Y 	c #929497",
    "Z 	c #875E2C",
    "` 	c #BA7012",
    " .	c #FDCC96",
    "..	c #FCB970",
    "+.	c #A58764",
    "@.	c #696A6C",
    "#.	c #BF8441",
    "$.	c #EB9F4A",
    "%.	c #FED9B1",
    "&.	c #F6B56E",
    "*.	c #777472",
    "=.	c #7F8083",
    "-.	c #898B8E",
    ";.	c #8A8C8F",
    ">.	c #9B5C06",
    ",.	c #F39526",
    "'.	c #F9A547",
    ").	c #FFFFFF",
    "!.	c #F7992B",
    "~.	c #DBB88F",
    "{.	c #CD8C43",
    "].	c #E49B48",
    "^.	c #FFE0BF",
    "/.	c #FEF7EE",
    "(.	c #F7B66E",
    "_.	c #CFCAC4",
    ":.	c #CDCED0",
    "<.	c #8C612E",
    "[.	c #995B05",
    "}.	c #C48842",
    "|.	c #FEE8CE",
    "1.	c #F9AB55",
    "2.	c #F79728",
    "3.	c #E4A867",
    "4.	c #6A6B6E",
    "5.	c #ADAFB2",
    "6.	c #91642E",
    "7.	c #9C5D06",
    "8.	c #95734D",
    "9.	c #F4972A",
    "0.	c #FAAC55",
    "a.	c #E6BB8A",
    "b.	c #CECFD1",
    "c.	c #9B6A2E",
    "d.	c #A26109",
    "e.	c #90724E",
    "f.	c #B7956F",
    "g.	c #EFC18F",
    "h.	c #A7A9AC",
    "i.	c #AAACAF",
    "j.	c #ABADB0",
    "k.	c #A8712E",
    "l.	c #AC670D",
    "m.	c #987853",
    "n.	c #CF995D",
    "o.	c #D3AB80",
    "p.	c #383839",
    "q.	c #4B4B4D",
    "r.	c #B87A2D",
    "s.	c #A36920",
    "t.	c #8F622D",
    "u.	c #815825",
    "v.	c #CF8733",
    "w.	c #F7982A",
    "x.	c #F8CFA0",
    "y.	c #8E8F92",
    "z.	c #999B9E",
    "A.	c #C37A21",
    "B.	c #B36C0F",
    "C.	c #9E5E07",
    "D.	c #8C5201",
    "E.	c #7E4A00",
    "F.	c #B77017",
    "G.	c #F49525",
    "H.	c #FBCA95",
    "I.	c #D2C0AD",
    "J.	c #C7C8CA",
    "K.	c #735A3C",
    "L.	c #624E38",
    "M.	c #554531",
    "N.	c #4C3E2E",
    "O.	c #564532",
    "P.	c #9B7447",
    "Q.	c #DB8E36",
    "R.	c #F19830",
    "S.	c #F1C390",
    "T.	c #B2AEAB",
    "U.	c #B9BBBD",
    "V.	c #C6C7C9",
    "W.	c #000000",
    "X.	c #68420C",
    "Y.	c #C2843C",
    "Z.	c #FEEFDC",
    "`.	c #E4B37D",
    " +	c #A4A29E",
    ".+	c #BBBCBF",
    "++	c #744A11",
    "@+	c #C7873E",
    "#+	c #DEA96F",
    "$+	c #A1A3A6",
    "%+	c #B1B3B5",
    "&+	c #BFC0C3",
    "*+	c #855516",
    "=+	c #BD823E",
    "-+	c #F9B56D",
    ";+	c #D19B60",
    ">+	c #977752",
    ",+	c #A9865D",
    "'+	c #BD9568",
    ")+	c #CDA171",
    "!+	c #D8A977",
    "~+	c #DFAF7A",
    "{+	c #E3B27C",
    "]+	c #E5B47D",
    "^+	c #E6B57E",
    "/+	c #5D4C3A",
    "(+	c #AC6D1E",
    "_+	c #C07923",
    ":+	c #A5630B",
    "<+	c #C67715",
    "[+	c #E5891B",
    "}+	c #ED8E1D",
    "|+	c #F3921E",
    "1+	c #F69727",
    "                                                                ",
    "                                                                ",
    "      . . . . . . . . . . . . . . . . .                         ",
    "      . . . . . . . . . . . . . . . . . .                       ",
    "    . . + @ @ @ @ @ @ @ @ @ @ @ @ @ @ . .                       ",
    "    # $ % @ @ @ @ @ @ @ @ @ @ @ & @ @ . .                       ",
    "    * = - ; > , ' , ) ) ) ' ' ' ! @ @ . .                       ",
    "    ~ { ] ^ / ) ) ) ) ) ( _ : : < + + . . . . . . . . .         ",
    "    [ . } | 1 ; @ @ @ 2 . . . . . . . . . . . . . . . . .       ",
    "    3 . 4 5 ^ 6 7 7 7 8 4 9 9 9 9 9 9 9 9 9 9 9 9 9 9 9 . .     ",
    "    0 . a b c d d e 7 8 4 9 9 9 9 9 9 9 9 9 9 9 9 9 9 9 . .     ",
    "    f . . g h 1 ; @ @ i 4 9 9 j k k k k k k k 7 l m 9 9 . .     ",
    "    n . . o p q j j @ i 4 9 m k ' ' ' ' ' r k k s 9 9 9 . .     ",
    "    t . . u v w x y z A B C C C 9 9 9 9 9 9 9 9 9 9 9 9 . .     ",
    "    D E . . F b G H G I J K L C C 9 9 9 M N N N M 9 9 9 . .     ",
    "    O P . Q . R w S w T U V W X d d d d d d d d Y 9 9 9 . .     ",
    "    Z ` .  .... +.@.r #.$.%.&.*.=.-.;.;.;.;.;.Y 9 9 9 9 . .     ",
    "    Z >.,.'.). .!.I ~.{.].^./.(._.:.C C 9 9 9 9 9 9 9 9 . .     ",
    "    <.[.}.. |.)./. .1.2.. %.)./.3.4.5.C C 9 9 9 9 9 9 9 . .     ",
    "    6.7.8.9.0.).).).).).).).).)./.a.& b.C 9 9 9 9 9 9 9 . .     ",
    "    c.d.e.f.. %.).).).).).).).).)./.g.h.i.j.N N / 9 9 9 . .     ",
    "    k.l.m.! n.!.|.).).).).).).).).)./.o.p.d d d q./ 9 9 . .     ",
    "    r.` s.t.u.v.w.%.).).).).).).).).).x.y.z.;.;.N 9 9 9 . .     ",
    "      A.B.C.D.E.F.G.0.%./.).).).).).H.I.J.:.C 9 9 9 9 9 . .     ",
    "          K.L.M.N.O.P.Q.R.^.).)./.S.T.U.V.:.C 9 9 9 9 9 . .     ",
    "                  W.W.X.Y.^.).Z.`. +i..+J.:.C 9 9 9 9 9 . .     ",
    "                    W.++@+^.^.#+y.$+%+&+& b.C 9 9 9 9 9 . .     ",
    "                      *+=+-+;+>+,+'+)+!+~+{+]+^+^+^+^+^+. .     ",
    "                      /+(+_+:+B.<+P [+}+|+$ . . . . . . 1+      ",
    "                                                                ",
    "                                                                ",
    "                                                                "]


plot_grid = [
    "32 32 2 1",
    " 	c None",
    ".	c #0BA14B",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "       ..      ..      .        ",
    "       ..      ..      .        ",
    "       ..      ..      .        ",
    "    ........................    ",
    "    .......................     ",
    "       ..      ..      .        ",
    "       ..      ..      .        ",
    "       ..      ..      .        ",
    "       ..      ..      .        ",
    "       ..      ..      .        ",
    "       ..      ..      .        ",
    "    ........................    ",
    "    .......................     ",
    "       ..      ..      .        ",
    "       ..      ..      .        ",
    "       ..      ..      .        ",
    "       ..      ..      .        ",
    "       ..      ..      .        ",
    "    .......................     ",
    "    ........................    ",
    "       ..      ..      .        ",
    "       ..      ..      .        ",
    "       ..      ..      .        ",
    "                                ",
    "                                ",
    "                                ",
    "                                "]


plot_xlog = [
    "32 32 4 1",
    " 	c None",
    ".	c #000000",
    "+	c #282828",
    "@	c #0BA14B",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "       ..                       ",
    "       ..                       ",
    "       ..                       ",
    "       ..     ...   .....       ",
    "       ..    ..... ......       ",
    "       ..    .. .. ..  ..       ",
    "       ..    .. .. ..  ..       ",
    "       ..    .. .. ..  ..       ",
    "       ..    .. .. ..  ..       ",
    "       ..... ..... ......       ",
    "       .....  ...   .....       ",
    "                       ..       ",
    "                    ....+       ",
    "      @@            ...  @      ",
    "    @@@@                 @@@    ",
    "   @@@@@@@@@@@@@@@@@@@@@@@@@@@  ",
    "    @@@@@@@@@@@@@@@@@@@@@@@@@   ",
    "     @@@                 @@     ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                "]


plot_ylog = [
    "32 32 3 1",
    " 	c None",
    ".	c #0BA14B",
    "+	c #000000",
    "                                ",
    "                                ",
    "                                ",
    "       .                        ",
    "      ..                        ",
    "      ...                       ",
    "     ....                       ",
    "     .....                      ",
    "      ..                        ",
    "      ..                        ",
    "      ..                        ",
    "      ..   ++                   ",
    "      ..   ++                   ",
    "      ..   ++                   ",
    "      ..   ++     ++    ++++    ",
    "      ..   ++    ++++  +++++    ",
    "      ..   ++   ++  ++++  ++    ",
    "      ..   ++   ++  ++++  ++    ",
    "      ..   ++   ++  ++++  ++    ",
    "      ..   ++   ++  ++++  ++    ",
    "      ..   ++++  ++++  +++++    ",
    "      ..   +++++  ++   +++++    ",
    "      ..                  ++    ",
    "      ..               +++++    ",
    "      ..               ++++     ",
    "     .....                      ",
    "     .....                      ",
    "      ...                       ",
    "      ...                       ",
    "       .                        ",
    "                                ",
    "                                "]


plot_toggle_points = [
    "32 32 3 1",
    " 	c None",
    ".	c #0BA14B",
    "+	c #00A651",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "       ..      ++               ",
    "       ..      ++               ",
    "       ..      ++               ",
    "       ..      ++               ",
    "       ..      ++               ",
    "       ..      ++               ",
    "       ..      ++               ",
    "       ..   +++++++   +++++++   ",
    "       ..   ++   ++   +++++++   ",
    "       ..   ++   ++   +++++++   ",
    "       ..   ++   ++   +++++++   ",
    "       ..   +++++++   +++++++   ",
    "       ..   +++++++   +++++++   ",
    "       ..      ++               ",
    "       ..      ++               ",
    "       ..      ++               ",
    "       ..      ++               ",
    "       ..      ++               ",
    "       ..      ++               ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                "]


plot_xauto = [
    "32 32 3 1",
    " 	c None",
    ".	c #000000",
    "+	c #0BA14B",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "           ...    ....          ",
    "           ....   ...           ",
    "            ...  ...            ",
    "             .......            ",
    "              .....             ",
    "              ....              ",
    "             ......             ",
    "             .......            ",
    "            ...  ....           ",
    "           ....   ...           ",
    "          ....    ....          ",
    "                                ",
    "      ++                 +      ",
    "    ++++                 +++    ",
    "   +++++++++++++++++++++++++++  ",
    "    +++++++++++++++++++++++++   ",
    "     +++                 ++     ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                "]


plot_yauto = [
    "32 32 3 1",
    " 	c None",
    ".	c #0BA14B",
    "+	c #000000",
    "                                ",
    "                                ",
    "        .                       ",
    "        ..                      ",
    "       ...                      ",
    "       ....                     ",
    "      .....                     ",
    "        ..                      ",
    "        ..                      ",
    "        ..                      ",
    "        ..    +++     +++       ",
    "        ..    ++++   ++++       ",
    "        ..     +++   +++        ",
    "        ..      +++ +++         ",
    "        ..      ++++++          ",
    "        ..       +++++          ",
    "        ..        +++           ",
    "        ..        +++           ",
    "        ..        +++           ",
    "        ..        +++           ",
    "        ..        +++           ",
    "        ..                      ",
    "        ..                      ",
    "        ..                      ",
    "      .....                     ",
    "      .....                     ",
    "       ....                     ",
    "       ...                      ",
    "        .                       ",
    "                                ",
    "                                ",
    "                                "]


plot_ydown = [
    "32 32 3 1",
    " 	c None",
    ".	c #000000",
    "+	c #0BA14B",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "    ..   ++    ...       ....   ",
    "   .. .  ++    ....      ...    ",
    "   .  .  ++     ....    ...     ",
    "   .  .  ++      ...   ...      ",
    "   .. .  ++       ...  ...      ",
    "    ..   ++       .......       ",
    "         ++        .....        ",
    "         ++         ...         ",
    "         ++         ...         ",
    "         ++         ...         ",
    "         ++         ...         ",
    "         ++         ...         ",
    "         ++         ...         ",
    "       ++++++                   ",
    "       ++++++                   ",
    "        ++++                    ",
    "        ++++                    ",
    "         ++                     ",
    "         +                      ",
    "                                ",
    "                                ",
    "                                ",
    "                                "]


plot_yup = [
    "32 32 3 1",
    " 	c None",
    ".	c #0BA14B",
    "+	c #000000",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "          ..                    ",
    "         ...                    ",
    "         ....                   ",
    "        .....                   ",
    "        ......                  ",
    "          ..    +++       ++++  ",
    "          ..    ++++      +++   ",
    "          ..     ++++    +++    ",
    "          ..      +++   +++     ",
    "          ..       +++  +++     ",
    "          ..       +++++++      ",
    "          ..        +++++       ",
    "     ++   ..         +++        ",
    "    ++ +  ..         +++        ",
    "    +  +  ..         +++        ",
    "    +  +  ..         +++        ",
    "    ++ +  ..         +++        ",
    "     ++   ..         +++        ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                "]


shape_circle_solid = [
    "32 32 2 1",
    " 	c None",
    ".	c #F7941E",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "              .....             ",
    "           ...........          ",
    "          .............         ",
    "         ...............        ",
    "        .................       ",
    "        .................       ",
    "       ...................      ",
    "       ...................      ",
    "      ....................      ",
    "      .....................     ",
    "      .....................     ",
    "      .....................     ",
    "       ...................      ",
    "       ...................      ",
    "       ...................      ",
    "        .................       ",
    "        .................       ",
    "         ...............        ",
    "          ............          ",
    "            .........           ",
    "                .               ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                "]


shape_ellipse_solid = [
    "32 32 2 1",
    " 	c None",
    ".	c #F7941E",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "            ........            ",
    "         ..............         ",
    "       ...................      ",
    "      .....................     ",
    "     .......................    ",
    "    .........................   ",
    "    .........................   ",
    "   ..........................   ",
    "   ..........................   ",
    "    .........................   ",
    "    .........................   ",
    "    ........................    ",
    "     ......................     ",
    "       ...................      ",
    "        ................        ",
    "           ..........           ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                ",
    "                                "]


zoom_original = [
    "32 32 178 2",
    "  	c None",
    ". 	c #ED1C24",
    "+ 	c #BB7E6D",
    "@ 	c #959598",
    "# 	c #8A888B",
    "$ 	c #80787B",
    "% 	c #79686C",
    "& 	c #C07A6A",
    "* 	c #D99B86",
    "= 	c #B0CAD6",
    "- 	c #8C9CA6",
    "; 	c #737578",
    "> 	c #756F72",
    ", 	c #B9B2B4",
    "' 	c #CFD3D7",
    ") 	c #CC8A76",
    "! 	c #DFAD9C",
    "~ 	c #F6FBFE",
    "{ 	c #D0E6F2",
    "] 	c #71797F",
    "^ 	c #6B6A6C",
    "/ 	c #A99C9D",
    "( 	c #E0E2E4",
    "_ 	c #A4D3EA",
    ": 	c #7FCBEB",
    "< 	c #BC8575",
    "[ 	c #E82A29",
    "} 	c #699CAB",
    "| 	c #C9EBFC",
    "1 	c #E4F3FB",
    "2 	c #676B6F",
    "3 	c #6D6668",
    "4 	c #847175",
    "5 	c #F1F1F1",
    "6 	c #C9DEE9",
    "7 	c #9DD2EC",
    "8 	c #80CBEB",
    "9 	c #5CC5EC",
    "0 	c #B48477",
    "a 	c #6299A9",
    "b 	c #D9F0FC",
    "c 	c #BFD8E4",
    "d 	c #48484B",
    "e 	c #A05A53",
    "f 	c #9E8E91",
    "g 	c #EEEEEF",
    "h 	c #BBDAEA",
    "i 	c #A1D3EB",
    "j 	c #85CDEB",
    "k 	c #66C6EB",
    "l 	c #3BC1EC",
    "m 	c #AE8377",
    "n 	c #E92A29",
    "o 	c #94A6AC",
    "p 	c #D7EFFB",
    "q 	c #73635E",
    "r 	c #E62727",
    "s 	c #B3A7A9",
    "t 	c #ECF0F2",
    "u 	c #C2DDEA",
    "v 	c #AAD5EB",
    "w 	c #90CFEB",
    "x 	c #75C9EB",
    "y 	c #56C4EC",
    "z 	c #33C0ED",
    "A 	c #AF8377",
    "B 	c #EA2829",
    "C 	c #B4897D",
    "D 	c #E62C29",
    "E 	c #B8ABAD",
    "F 	c #F0F1F2",
    "G 	c #CCDFE9",
    "H 	c #B6D9EB",
    "I 	c #9FD2EB",
    "J 	c #88CDEB",
    "K 	c #71C8EC",
    "L 	c #59C4EC",
    "M 	c #44C2EC",
    "N 	c #D2614B",
    "O 	c #B5A8AA",
    "P 	c #DAE4E9",
    "Q 	c #C3DDE9",
    "R 	c #B0D7EB",
    "S 	c #89CDEB",
    "T 	c #7ACAEB",
    "U 	c #6EC8EC",
    "V 	c #68C6EB",
    "W 	c #DD5641",
    "X 	c #C14D3A",
    "Y 	c #918184",
    "Z 	c #F3F3F3",
    "` 	c #E7E8E9",
    " .	c #D5E3E9",
    "..	c #C1DCEA",
    "+.	c #B0D7EA",
    "@.	c #A2D3EB",
    "#.	c #95D0EB",
    "$.	c #8DCEEB",
    "%.	c #B6A6A2",
    "&.	c #EB2728",
    "*.	c #E72728",
    "=.	c #D8D2D3",
    "-.	c #E6E6E7",
    ";.	c #E6E8E9",
    ">.	c #D6E3EA",
    ",.	c #C5DDEA",
    "'.	c #BADAEB",
    ").	c #AFD7EB",
    "!.	c #C6AA9F",
    "~.	c #E03F2F",
    "{.	c #EC2B29",
    "].	c #8F7D81",
    "^.	c #E2E1E2",
    "/.	c #DEDFE0",
    "(.	c #DDE5E9",
    "_.	c #D1E1E9",
    ":.	c #D9AE9D",
    "<.	c #EC2728",
    "[.	c #D26147",
    "}.	c #595A5C",
    "|.	c #BD5041",
    "1.	c #EC2E2A",
    "2.	c #98898C",
    "3.	c #D3D3D5",
    "4.	c #CECED0",
    "5.	c #DCDDDE",
    "6.	c #EAB09B",
    "7.	c #ED2728",
    "8.	c #CF634A",
    "9.	c #67686A",
    "0.	c #706165",
    "a.	c #634D53",
    "b.	c #BF5042",
    "c.	c #EA513C",
    "d.	c #C8B4B0",
    "e.	c #847376",
    "f.	c #ADA5A7",
    "g.	c #C3A79B",
    "h.	c #EA2F2A",
    "i.	c #C3664D",
    "j.	c #7D787A",
    "k.	c #79696D",
    "l.	c #4B3B3F",
    "m.	c #443036",
    "n.	c #594349",
    "o.	c #BA4C3F",
    "p.	c #EA4F3B",
    "q.	c #D3C0BE",
    "r.	c #E92227",
    "s.	c #C7503F",
    "t.	c #7A696D",
    "u.	c #412E33",
    "v.	c #513B41",
    "w.	c #B7493D",
    "x.	c #E84D3A",
    "y.	c #E0CBCA",
    "z.	c #453438",
    "A.	c #493339",
    "B.	c #B2453B",
    "C.	c #E64B39",
    "D.	c #DFC9C9",
    "E.	c #C3C0C4",
    "F.	c #46363A",
    "G.	c #C13A31",
    "H.	c #E34937",
    "I.	c #DEC4C3",
    "J.	c #D0CBD0",
    "K.	c #4B3135",
    "L.	c #CA322D",
    "M.	c #BC7C72",
    "N.	c #CCBCC3",
    "O.	c #C2BEC3",
    "P.	c #4E373A",
    "Q.	c #C7302C",
    "R.	c #944B45",
    "S.	c #7C676E",
    "T.	c #97898E",
    "U.	c #5E4B4F",
    "                                                                ",
    "                                                                ",
    "                                                                ",
    "                                                                ",
    "                                                                ",
    "                                                                ",
    "              . .                               . .             ",
    "              . . . + @ # $ %                 . . . .           ",
    "              & . . . * = - ; >             . . . .             ",
    "            , ' ) . . . ! ~ { ] ^         . . . .               ",
    "          / ( _ : < . . [ } | 1 2 3     . . . .                 ",
    "        4 5 6 7 8 9 0 . . [ a b c d e . . . .                   ",
    "        f g h i j k l m . . n o p q r . . .                     ",
    "        s t u v w x y z A . . B C D . . .                       ",
    "        E F G H I J K L M N . . . . . .                         ",
    "        O g P Q R 7 S T U V W . . . X                           ",
    "        Y Z `  ...+.@.#.$.%.&.. . . *.                          ",
    "          =.-.;.>.,.'.).!.&.. . ~.. . {.                        ",
    "          ].^./.` (._.:.<.. . [.}.|.. . 1.                      ",
    "            2.3.4.5.6.7.. . 8.9.0.a.b.. . c.d.                  ",
    "              e.f.g.h.. . i.j.k.l.m.n.o.. . p.q.                ",
    "                  r.. . s.t.        u.v.w.. . x.y.              ",
    "                . . . .               z.A.B.. . C.D.E.          ",
    "              . . . .                   F.m.G.. . H.I.J.        ",
    "              . . .                         K.L.. . M.N.O.      ",
    "                .                             P.Q.R.S.T.        ",
    "                                                F.m.U.          ",
    "                                                                ",
    "                                                                ",
    "                                                                ",
    "                                                                ",
    "                                                                "]
